@@ -680,3 +680,36 @@ func TestShowFile(t *testing.T) {
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'v', 0))
 	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'q', 0))
 }
+
+func TestShowInfoAndMoveAround(t *testing.T) {
+	fin := testdir.CreateTestDir()
+	defer fin()
+	simScreen := testapp.CreateSimScreen(50, 50)
+	defer simScreen.Fini()
+
+	app := testapp.CreateMockedApp(true)
+	ui := CreateUI(app, simScreen, &bytes.Buffer{}, false, true)
+	ui.done = make(chan struct{})
+	err := ui.AnalyzePath("test_dir", nil)
+	assert.Nil(t, err)
+
+	<-ui.done // wait for analyzer
+
+	for _, f := range ui.app.(*testapp.MockedApp).UpdateDraws {
+		f()
+	}
+
+	assert.Equal(t, "test_dir", ui.currentDir.Name)
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRight, 'l', 0))
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'i', 0))
+
+	assert.True(t, ui.pages.HasPage("info"))
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'k', 0)) // move up
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'j', 0)) // move down
+
+	ui.keyPressed(tcell.NewEventKey(tcell.KeyRune, 'q', 0))
+
+	assert.False(t, ui.pages.HasPage("info"))
+}
